# SubFucker

SubFUcker is a tool desinged to help bughunters enumirate subdomain statuscodes.
You can use this tool when you want to test a target and that target has more than 1000 subdomains or 
more to get status codes and http schema of the subdomains without needing to open them manualy 

![alt tag](https://github.com/TheXerr0r/SubFucker/blob/main/SubFuckerScreenShoot.png)

# Usage

  - subfucker -f inputfile -o outfile -t thread

# Installation

 - git clone https://github.com/TheXerr0r/SubFucker
 - cd SubFucker
 - python3 setup.py install
 
## or
- python3 -m pip install SubFucker

![alt tag](https://image.ibb.co/i4ES3U/bc.png)

![alt tag](https://raw.githubusercontent.com/ehs4nnn/EY-Console/master/BITCOIN%20QR.png)
                 
 If You Want To See Our Private Tools, Please Send Your Donates To Montivate Us Publish Our Private Tool :)
 
 
 BitCoin Address: 1NZtHATWTyzmb1PghFrvwDDmVUCfCLNQWm
